4.45. umbra.ui.nodes — Umbra 1.0.9 documentation

# 4.45. umbra.ui.nodes

nodes.py

Platform:
  Windows, Linux, Mac Os X.
Description:
  Defines the Application nodes classes.

Others:

## 4.45.1. Module Attributes

`umbra.ui.nodes.` `LOGGER`

## 4.45.2. Classes

class `umbra.ui.nodes.` `Mixin_GraphModelObject`

  Bases: `object`

  Defines a mixin used to bring common capabilities in Application Nodes classes.

  Initializes the class.

  `roles`

    Property for self.__roles attribute.

    Returns: | self.__roles.
    Return type: | dict

  `flags`

    Property for self.__flags attribute.

    Returns: | self.__flags.
    Return type: | int

  `triggerModel`

    Property for self.__triggerModel attribute.

    Returns: | self.__triggerModel.
    Return type: | bool

class `umbra.ui.nodes.` `GraphModelAttribute`(name=None, value=None, roles=None, flags=None, **kwargs)

  Bases: `foundations.nodes.Attribute`, `umbra.ui.nodes.Mixin_GraphModelObject`

  Defines a storage object for the `GraphModelNode` class attributes.

  Initializes the class.

  Parameters: | name (unicode) – Attribute name. value (object) – Attribute value. roles (dict) – Roles. flags (int) – Flags. **kwargs (**) – Keywords arguments.

  `attributeChanged`()

    Triggers the host model(s) `umbra.ui.models.GraphModel.attributeChanged()` method.

    Returns: | Method success.
    Return type: | bool

class `umbra.ui.nodes.` `GraphModelNode`(name=None, parent=None, children=None, roles=None, flags=None, **kwargs)

  Bases: `foundations.nodes.AbstractCompositeNode`, `umbra.ui.nodes.Mixin_GraphModelObject`

  Defines `GraphModel` class base Node object.

  Initializes the class.

  Parameters: | name (unicode) – Node name. parent (AbstractNode or AbstractCompositeNode) – Node parent. children (list) – Children. roles (dict) – Roles. flags – Flags. ( Qt.ItemFlag ) **kwargs (**) – Keywords arguments.

  `nodeChanged`()

    Triggers the host model(s) `umbra.ui.models.GraphModel.nodeChanged()` method.

    Returns: | Method success.
    Return type: | bool

class `umbra.ui.nodes.` `DefaultNode`(name=None, parent=None, children=None, **kwargs)

  Bases: `foundations.nodes.AbstractCompositeNode`

  Defines the default Node used in `GraphModel` class model.
  This simple Node is used as an invisible root Node for `GraphModel` class models.

  Initializes the class.

  Parameters: | name (unicode) – Node name. parent (AbstractCompositeNode) – Node parent. children (list) – Children. **kwargs (**) – Keywords arguments.

class `umbra.ui.nodes.` `FormatNode`(name=None, parent=None, children=None, format=None, **kwargs)

  Bases: `foundations.nodes.AbstractCompositeNode`

  Defines the format base Node object.

  Initializes the class.

  Parameters: | name (unicode) – Node name. parent (AbstractNode or AbstractCompositeNode) – Node parent. children (list) – Children. format (object) – Format. **kwargs (**) – Keywords arguments.

  `format`

    Property for self.__format attribute.

    Returns: | self.__format.
    Return type: | object